#
# spec file for package libnma
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
%define base_ver 1.8

Name:           libnma
Version:        1.8.32
Release:        150400.1.8
Summary:        Shared library for NetworkManager-applet
License:        GPL-2.0-or-later
URL:            https://gitlab.gnome.org/GNOME/libnma
Source0:        https://download.gnome.org/sources/%{name}/%{base_ver}/%{name}-%{version}.tar.xz

BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gck-1) >= 3.14
BuildRequires:  pkgconfig(gcr-3) >= 3.14
BuildRequires:  pkgconfig(gio-2.0) >= 2.38
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.9.6
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libnm) >= 1.7
BuildRequires:  pkgconfig(mobile-broadband-provider-info)
BuildRequires:  pkgconfig(vapigen)

%description
Shared library for NetworkManager-applet.

%package -n     %{name}%{sover}
Summary:        Shared library for NetworkManager-applet
# Make lang package installable.
Provides:       %{name}
# Since version 1.8.28
Obsoletes:      nma-data < %{version}
Provides:       nma-data = %{version}
Obsoletes:      libnma-data < %{version}
Provides:       libnma-data = %{version}
Requires:       mobile-broadband-provider-info

%description -n %{name}%{sover}
Shared library for NetworkManager-applet.

%package -n     typelib-1_0-NMA-1_0
Summary:        Introspection bindings for %{name}

%description -n typelib-1_0-NMA-1_0
Introspection bindings for %{name}.

%package        devel
Summary:        Development Files for %{name}
Requires:       %{name}%{sover} = %{version}
Requires:       typelib-1_0-NMA-1_0 = %{version}

%description    devel
Development Files for %{name}.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%doc NEWS
%{_libdir}/%{name}.so.*
%{_datadir}/glib-2.0/schemas/org.gnome.nm-applet.gschema.xml

%files -n typelib-1_0-NMA-1_0
%{_libdir}/girepository-1.0/NMA-1.0.typelib

%files devel
%doc %{_datadir}/gtk-doc/html/%{name}/
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/gir-1.0/NMA-1.0.gir
%{_datadir}/vala/vapi/libnma.deps
%{_datadir}/vala/vapi/libnma.vapi

%files lang -f %{name}.lang

%changelog
* Fri Aug 20 2021 bjorn.lie@gmail.com
- Update to version 1.8.32:
  + Fix crash in PKCS11 login dialog.
  + Fix clearing password when restoring a valid configuration to
    be displayed to a user.
* Tue Jun 23 2020 bjorn.lie@gmail.com
- Update to version 1.8.30:
  + Properly dispose wireless security objects.
  + Don't clear the key when users set a non-pkcs12 certificate in
    the certificate chooser UI.
  + Added missing VAPI macro file.
- Drop libnma-fix-segment-fault.patch: Fixed upstream.
* Thu Jun  4 2020 songchuan.kang@suse.com
- Make libnma require mobile-broadband-provider-info(bsc#1172499).
* Fri Apr 17 2020 songchuan.kang@suse.com
- Add libnma-fix-segment-fault.patch: nma-ws: properly dispose
  wireless security objects(bsc#1168347 glgo#GNOME/libnma#7).
* Fri Mar  6 2020 bjorn.lie@gmail.com
- Update to version 1.8.28:
  + Turned the wireless-security library to a public API.
  + "org.gnome.nm-applet.gschema.xml" is now part of libnma.
    Previously, on distributions like Fedora it was packaged as
    part of nm-connection-editor package. But the schema is used by
    wireless-security library, gnome-control-center and
    nm-a/nm-c-e.
  + Clear key/password input fields when selecting a different
    certificate in NMACertChooser.
  + Generate vapi files.
- Add pkgconfig(vapigen) BuildRequires: New dependency.
- Drop nma-data Requires: No longer needed. Add nma-data and
  libnma-data Provides and Obsoletes, make upgrades problemfree
  for our end-users.
* Mon Dec  9 2019 dimstar@opensuse.org
- Require nma-data by libnma0: the library references the
  org.gnome.nm-applet schema, which is packaged in nma-data
  (boo#1157889).
* Mon Oct 28 2019 bjorn.lie@gmail.com
- Add virtual libnma Provides in the main lib package, make the
  lang package installable.
* Fri Oct 18 2019 bjorn.lie@gmail.com
- Inital packaging for openSUSE, version 1.8.26.
